pub struct PhaseCheckpoint {
pub id: String,
pub run_id: String,
pub topology_name: String,
pub phase_name: String,
pub sender_id: String,
pub project: String,
pub status: String,
pub output: Option<String>,
pub error_message: Option<String>,
pub attempt: i64,
pub created_at: String,
pub updated_at: String,
}Expand description
A recorded snapshot of one pipeline phase within a run.
Fields
id: StringUnique row identifier.
run_id: StringUUID identifying the enclosing pipeline run.
topology_name: StringName of the topology (e.g. "my-pipeline").
phase_name: StringName of the phase within the topology.
sender_id: StringAgent / sender identifier that owns this run.
project: StringProject scope. Empty string = no project.
status: StringOne of "pending", "in_progress", "completed", "failed".
output: Option<String>Phase output text. None until the phase completes successfully.
error_message: Option<String>Error detail. Set only when status is "failed".
attempt: i64How many attempts have been made for this phase (0-indexed).
created_at: StringISO-8601 creation timestamp.
updated_at: StringISO-8601 last-update timestamp.